package main

import (
	"bytes"
	"fmt"
	"io/ioutil"
	"strconv"
	"strings"
)

const (
	RESULT_IMPOSSIBLE = iota
	RESULT_BOARD_CONF = iota
)

func drawLine(board [][]byte, r int, c int, f byte) {
	for i := 0; i < c; i++ {
		board[r][i] = f
	}
}

func drawArea(board [][]byte, r int, c int, f byte) {
	for i := 0; i < r; i++ {
		drawLine(board, i, c, f)
	}
}

func solve(r int, c int, m int) ([][]byte, int) {
	// init board
	board := make([][]byte, r)
	for i := range board {
		board[i] = make([]byte, c)
	}
	drawArea(board, r, c, '.')

	emptyCellCount := r*c - m

	switch {
	case emptyCellCount == 1:
		drawArea(board, r, c, '*')
		board[r-1][c-1] = 'c'

		return board, RESULT_BOARD_CONF
	case c == 1:
		drawArea(board, m, c, '*')
		board[r-1][c-1] = 'c'

		return board, RESULT_BOARD_CONF

	case emptyCellCount == 2, emptyCellCount == 3:
		return board, RESULT_IMPOSSIBLE
	case c == 2:
		if m%2 == 0 {
			drawArea(board, m/2, c, '*')
			board[r-1][c-1] = 'c'

			return board, RESULT_BOARD_CONF
		} else {
			return board, RESULT_IMPOSSIBLE
		}

	case emptyCellCount == 5, emptyCellCount == 7:
		return board, RESULT_IMPOSSIBLE
	case emptyCellCount <= 9:
		drawArea(board, r-3, c, '*')
		for i := r - 3; i < r; i++ {
			for j := 0; j < (c - 3); j++ {
				board[i][j] = '*'
			}
		}

		switch emptyCellCount {
		case 4:
			board[r-3][c-1] = '*'
			board[r-3][c-2] = '*'
			board[r-3][c-3] = '*'
			board[r-2][c-3] = '*'
			board[r-1][c-3] = '*'
		case 6:
			board[r-3][c-3] = '*'
			board[r-2][c-3] = '*'
			board[r-1][c-3] = '*'
		case 8:
			board[r-3][c-3] = '*'
		case 9:
		}

		board[r-1][c-1] = 'c'

		return board, RESULT_BOARD_CONF
	case emptyCellCount > 9:
		if emptyCellCount >= 3*c {
			drawArea(board, m/c, c, '*')

			left := m % c
			if left <= (c - 2) {
				drawLine(board, m/c, left, '*')
				board[r-1][c-1] = 'c'

				return board, RESULT_BOARD_CONF
			} else { // left == c - 1
				drawLine(board, m/c, c-2, '*')
				drawLine(board, m/c+1, 1, '*')
				board[r-1][c-1] = 'c'

				return board, RESULT_BOARD_CONF
			}
		} else { // 9 < emptyCellCount < 3*c
			drawArea(board, r-3, c, '*')

			left := m - ((r - 3) * c)

			for i := 0; i < left/3; i++ {
				for j := r - 3; j < r; j++ {
					board[j][i] = '*'
				}
			}

			switch left % 3 {
			case 1:
				board[r-3][left/3] = '*'
			case 2:
				board[r-3][left/3] = '*'
				board[r-3][left/3+1] = '*'
			}

			board[r-1][c-1] = 'c'

			return board, RESULT_BOARD_CONF
		}
	}

	return board, RESULT_IMPOSSIBLE
}

func drawBoard(board [][]byte, transpose bool) string {
	var buffer bytes.Buffer

	r := len(board)
	c := len(board[0])

	if transpose {
		for i := 0; i < c; i++ {
			for j := 0; j < r; j++ {
				//buffer.WriteString(string(board[r-j-1][c-i-1]))
				buffer.WriteString(string(board[j][i]))
			}
			buffer.WriteString("\n")
		}
	} else {
		for i := 0; i < r; i++ {
			for j := 0; j < c; j++ {
				//buffer.WriteString(string(board[r-i-1][c-j-1]))
				buffer.WriteString(string(board[i][j]))
			}
			buffer.WriteString("\n")
		}
	}

	return buffer.String()
}

func main() {
	content, _ := ioutil.ReadFile("C-large-practice.in")
	lines := strings.Split(string(content), "\n")

	caseNum, _ := strconv.Atoi(lines[0])

	for i := 0; i < caseNum; i++ {
		line := strings.Split(lines[i+1], " ")

		r, _ := strconv.Atoi(line[0])
		c, _ := strconv.Atoi(line[1])
		m, _ := strconv.Atoi(line[2])

		var board [][]byte
		var status int
		if r > c {
			board, status = solve(r, c, m)
		} else {
			board, status = solve(c, r, m)
		}

		switch status {
		case RESULT_IMPOSSIBLE:
			fmt.Printf("Case #%d:\nImpossible\n", i+1)
		case RESULT_BOARD_CONF:
			fmt.Printf("Case #%d:\n", i+1)

			if r > c {
				fmt.Print(drawBoard(board, false))
			} else {
				fmt.Print(drawBoard(board, true))
			}
		}
	}
}
