package main

import (
	"fmt"
	"io/ioutil"
	"sort"
	"strconv"
	"strings"
)

// return true if ken wins
func kenPlay(naoWeight float64, kenMass *[]float64) bool {
	for i := range *kenMass {
		if (*kenMass)[i] > naoWeight {
			*kenMass = append((*kenMass)[:i], (*kenMass)[i+1:]...)
			return true
		}
	}

	*kenMass = (*kenMass)[1:]
	return false
}

func solveDWar(n int, naoMass []float64, kenMass []float64) int {
	naoMassCopy := append([]float64(nil), naoMass...)

	naoScore := 0
	for i := 0; i < n; i++ {
		if kenMass[i] > naoMassCopy[len(naoMassCopy)-1] {
			break
		}

		for j := range naoMassCopy {
			if naoMassCopy[j] > kenMass[i] {
				naoMassCopy = append(naoMassCopy[:j], naoMassCopy[j+1:]...)
				naoScore++

				break
			}
		}
	}

	return naoScore
}

func solveWar(n int, naoMass []float64, kenMass []float64) int {
	kenMassCopy := append([]float64(nil), kenMass...)

	naoScore := 0
	for i := 0; i < n; i++ {
		if !kenPlay(naoMass[i], &kenMassCopy) {
			naoScore++
		}
	}

	return naoScore
}

func solve(n int, naoMass []float64, kenMass []float64) (int, int) {
	return solveDWar(n, naoMass, kenMass), solveWar(n, naoMass, kenMass)
}

func main() {
	content, _ := ioutil.ReadFile("D-large-practice.in")
	lines := strings.Split(string(content), "\n")

	caseNum, _ := strconv.Atoi(lines[0])

	for i := 0; i < caseNum; i++ {
		n, _ := strconv.Atoi(lines[i*3+1])

		naoLine := strings.Split(lines[i*3+2], " ")
		kenLine := strings.Split(lines[i*3+3], " ")

		naoMass := make([]float64, n)
		kenMass := make([]float64, n)

		for i := range naoLine {
			w, _ := strconv.ParseFloat(naoLine[i], 64)

			naoMass[i] = w
		}
		for i := range kenLine {
			w, _ := strconv.ParseFloat(kenLine[i], 64)

			kenMass[i] = w
		}

		sort.Float64s(naoMass)
		sort.Float64s(kenMass)

		dWarScore, warScore := solve(n, naoMass, kenMass)
		fmt.Printf("Case #%d: %d %d\n", i+1, dWarScore, warScore)
	}
}
